@@ -15,7 +15,7 @@ Binomial.SGoF=max(min(n*ecdf(u)(gamma)-b[min(which((1-pbinom(b-1,n,gamma))<=alph
 
 su<-sort(u)
 jj<-which(u==1)
-if(length(jj)!=0) pi0<-(-1/n)*sum(log(1-u[-jj])) else pi0<-(-1/n)*sum(log(1-u))
+if(length(jj)!=0) pi0<-1 else pi0<-min((-1/n)*sum(log(1-u)),1)
 
 if(Binomial.SGoF==0){FDR_BS<-0}else{FDR_BS<-round((pi0*su[Binomial.SGoF])/(ecdf(u)(su[Binomial.SGoF])),4)}
 
@@ -43,7 +43,7 @@ auu=rep(1,n)
 for (i in 1:Nmax) {auu[i]=min(su[as.integer(n*ecdf(su)(su[i]))<=N2])}
 
 
-return(c(list(Rejections=Binomial.SGoF,FDR=FDR_BS,Adjusted.pvalues=auu)))
+return(c(list(Rejections=Binomial.SGoF,FDR=min(FDR_BS,1),Adjusted.pvalues=auu)))
 }
 
 
